==> igniteui-webcomponents-core-3.2.0.tgz: package/esm5/lib/NativeUILabel.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { NativeUIComponent } from "./NativeUIComponent";
import { markType } from "./type";
/**
 * @hidden
 */
var NativeUILabel = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(NativeUILabel, _super);
    function NativeUILabel() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    NativeUILabel.prototype.get_c = function () {
        return 3;
    };
    Object.defineProperty(NativeUILabel.prototype, "aq", {
        get: function () {
            var a = this.o(8);
            return a;
        },
        set: function (a) {
            this.ad(8, a);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(NativeUILabel.prototype, "ap", {
        get: function () {
            var a = this.o(9);
            return a;
        },
        set: function (a) {
            this.ad(9, a);
        },
        enumerable: true,
        configurable: true
    });
    NativeUILabel.$t = markType(NativeUILabel, 'NativeUILabel', NativeUIComponent.$);
    return NativeUILabel;
}(NativeUIComponent));
export { NativeUILabel };

==> igniteui-webcomponents-core-3.5.0.tgz: package/esm5/lib/NativeUILabel.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { NativeUIComponent } from "./NativeUIComponent";
import { markType } from "./type";
/**
 * @hidden
 */
var NativeUILabel = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(NativeUILabel, _super);
    function NativeUILabel() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    NativeUILabel.prototype.get_c = function () {
        return 3;
    };
    Object.defineProperty(NativeUILabel.prototype, "au", {
        get: function () {
            var a = this.o(8);
            return a;
        },
        set: function (a) {
            this.af(8, a);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(NativeUILabel.prototype, "at", {
        get: function () {
            var a = this.o(9);
            return a;
        },
        set: function (a) {
            this.af(9, a);
        },
        enumerable: true,
        configurable: true
    });
    NativeUILabel.$t = markType(NativeUILabel, 'NativeUILabel', NativeUIComponent.$);
    return NativeUILabel;
}(NativeUIComponent));
export { NativeUILabel };
